% HISTORY
%
% 2013-09-18 Created initial style file, Alexei Gilchrist
% 2013-09-21 Updated structures on suggestions, Alexei Gilchrist
%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{mqassessment}[2013/10/21 MQ Assignment class]

\usepackage{newtxtext}

\RequirePackage{ifthen}


%-----------------------------------------------------------------
% options
%-----------------------------------------------------------------
\newboolean{exam}
\setboolean{exam}{false}
\DeclareOption{exam}{\setboolean{exam}{true}}
\newboolean{resetquestions}
\setboolean{resetquestions}{false}
\DeclareOption{resetquestions}{\setboolean{resetquestions}{true}}

% finished processing options
\ProcessOptions\relax

\LoadClass[12pt, a4paper]{article}


%-----------------------------------------------------------------
% packages
%-----------------------------------------------------------------
\usepackage{amsmath,amsfonts,amssymb}

% load this after amsmath
\usepackage{newtxmath}

\usepackage[pdftex,colorlinks=true,urlcolor=blue,linkcolor=blue,citecolor=blue,pdfstartview=FitH]{hyperref}
\usepackage{graphicx}
\usepackage{xcolor}
\usepackage{mdframed}

% Page layout
\usepackage[includeheadfoot,headheight=2cm,left=2.5cm,right=2.5cm,top=.5cm,bottom=2cm]{geometry}
\usepackage{fancyhdr}


%-----------------------------------------------------------------
% title page
%-----------------------------------------------------------------
\newcommand{\Vunitcode}{}
\newcommand{\Vunitname}{}
\newcommand{\Vtimeallowed}{}
\newcommand{\Vtotalquestions}{}
\newcommand{\Vtotalmarks}{}
\newcommand{\Vinstructions}{}
\newcommand{\Vpermitted}{}
\newcommand{\unitcode}[1]{\renewcommand{\Vunitcode}{#1}}
\newcommand{\unitname}[1]{\renewcommand{\Vunitname}{#1}}
\newcommand{\timeallowed}[1]{\renewcommand{\Vtimeallowed}{#1}}
\newcommand{\totalquestions}[1]{\renewcommand{\Vtotalquestions}{#1}}
\newcommand{\totalmarks}[1]{\renewcommand{\Vtotalmarks}{#1}}
\newcommand{\instructions}[1]{\renewcommand{\Vinstructions}{#1}}
\newcommand{\permitted}[1]{\renewcommand{\Vpermitted}{#1}}


\ifthenelse{\boolean{exam}}%
{% if it's an exam add cover page
\def\maketitle{
\pagestyle{empty}
\begin{center}
\includegraphics[height=5.0cm]{MQlogoV} \\[2cm]
\textbf{\Large{\@title}} \\[2cm]
\begin{tabular}{rl}
  \textbf{Unit Code and Name}: & \Vunitcode \quad\Vunitname \\[1em]
  %\textbf{Date}: & \@date \\[1em]
  \textbf{Time Allowed:}  & 
      \begin{minipage}[t]{9cm}
          \Vtimeallowed
      \end{minipage} \vspace{1em} \\
  \textbf{Total Number of Questions:} & 
      \begin{minipage}[t]{9cm}
          \Vtotalquestions
      \end{minipage} \vspace{1em} \\
  \textbf{Total Marks:} & \Vtotalmarks \\[1em]
  \textbf{Instructions:}  & 
      \begin{minipage}[t]{9cm}
          \Vinstructions
      \end{minipage} \vspace{1em} \\
  \textbf{Materials Allowed:} & 
      \begin{minipage}[t]{9cm}
          \Vpermitted
      \end{minipage} 
\end{tabular} 
\end{center}
\newpage
\pagestyle{fancy}
  }
}{% if it's an assignment a short title
\def\maketitle{
    \begin{center}
      \textbf{\huge\@title} \\[.5cm]
      {\large Due: \@date}
   \end{center}
   \pagestyle{fancy} }
}


%-----------------------------------------------------------------
% page and text format
%-----------------------------------------------------------------
% Paragraph formatting
\setlength{\parindent}{0ex}
\setlength{\parskip}{2ex}

% headers
\lhead{\bfseries\large\Vunitcode}
\chead{}
\rhead{\includegraphics[width=4cm]{MQlogoH}}
\lfoot{}
\cfoot{\thepage}
\rfoot{}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0.4pt}

% a little less space between section label and title:
\renewcommand*{\@seccntformat}[1]{%
  \csname the#1\endcsname\,
}

%-----------------------------------------------------------------
% Questions and sub-questions
%-----------------------------------------------------------------
\newcounter{question}
\newcounter{subquestion}[question]
\newcounter{tmpcounter} % used to maintain numbering across instances
\setcounter{tmpcounter}{0}

% style of the labels
\renewcommand{\thequestion}{\arabic{question}}
\newcommand{\labelquestion}{\bfseries\large Question~\thesection\thequestion}

\renewcommand{\thesubquestion}{\alph{subquestion}}
\newcommand{\labelsubquestion}{\bfseries(\thesubquestion)}

% make default enumerate match at 3rd and 4th level
\renewcommand{\theenumi}{\roman{enumi}}
\renewcommand{\theenumii}{\Alph{enumii}}
\renewcommand{\labelenumi}{\theenumi.}
\renewcommand{\labelenumii}{\theenumii.}

\renewcommand{\thesection}{\Alph{section}}

% fix the prefactors in referencing
\makeatletter 
\renewcommand{\p@question}{\thesection}
\renewcommand{\p@subquestion}{\thesection\thequestion}
\renewcommand{\p@enumi}{\thesection\thequestion(\thesubquestion)}
\renewcommand{\p@enumii}{\thesection\thequestion(\thesubquestion)\theenumi.}
\makeatother

% define questions environment
\newenvironment{questions}
{
  \begin{list}
  {\labelquestion}% list label
  {% list setup
    \usecounter{question}
    \ifthenelse{\boolean{resetquestions}}{}{\setcounter{question}{\thetmpcounter}}
    \setlength{\labelwidth}{0in}
    \setlength{\leftmargin}{0in}
    \setlength{\labelsep}{0.5ex}
    \setlength{\itemsep}{2em}
    }% list setup
}
{ 
  \ifthenelse{\boolean{resetquestions}}{}{\setcounter{tmpcounter}{\thequestion}}
  \end{list}
}

% define subquestions environment
\newenvironment{subquestions}
{
  \begin{list}
  {\labelsubquestion}% list label
    {% list setup
    \usecounter{subquestion}
    \setlength{\labelwidth}{1cm}
    \setlength{\leftmargin}{1cm}
    \setlength{\rightmargin}{0.5cm}
    \setlength{\labelsep}{0.7ex}
    \setlength{\itemsep}{0.5em}
    \setlength{\topsep}{0em}
    }% list setup
}
{ 
  \end{list}
}


%\newcommand{\question}[1][]{\item[] #1$\,\!$}
\newcommand{\question}[1][]{
\ifthenelse{ \equal {#1} {} }%
{\item }% if #1 == blank
{\item[#1] }% else (not blank)
$\,\!$}

\newcommand{\subquestion}[2][]{
\ifthenelse{ \equal {#1} {} }%
{\item\textbf{[#2]}}% if #1 == blank
{\item[#1]\textbf{[#2]}}% else (not blank)
$\,\!$}

%-----------------------------------------------------------------
% \easy \medium and \hard indicators
%-----------------------------------------------------------------
\definecolor{orange}{rgb}{1,0.5,0}
\definecolor{lgray}{gray}{0.90}
\newcommand{\easy}{{\color{orange}$\bigstar$}{\color{lgray}$\bigstar\bigstar$}}
\newcommand{\medium}{{\color{orange}$\bigstar\bigstar$}{\color{lgray}$\bigstar$}}
\newcommand{\hard}{{\color{orange}$\bigstar\bigstar\bigstar$}}


